using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using J4L.Vision;
using J4L.Vision.Util;
using J4L.Vision.PDF417;


public class PDF417Sample {
	
	
	private string[] testSet={ "macropdf.jpg","pdf2_180.jpg","pdf2_270.jpg","pdf2_90.jpg","pdf8.jpg","pdf7.jpg","pdf6.jpg","pdf5.png","pdf4.png","pdf3.jpg","pdf2.jpg","PDF417_1.png" ,"pdf2_corrupt3.jpg","pdf2_corrupt2.jpg","pdf2_corrupt.jpg","pdfbig.jpg","pdf_multiple.png","pdf417scan.jpg"};
	
	
	
	private string dir="images\\";
	
		
	[STAThread]
	public static void Main(string[] args)
	{
	
		J4L.Vision.Util.SystemProperties.registerAppArgs(args);		
		PDF417Sample sample=new PDF417Sample();
		try {
			
			
			sample.runTests();
		} catch (Exception e) {

			Console.WriteLine(e.Message);
			Console.WriteLine(e.StackTrace);
		}
		
		
	}
	
	/**
	 * read all test files
	 *
	 */
	public void runTests() {		
		// these are the default values
		SystemProperties.setProperty("minArea","60");
		SystemProperties.setProperty("maxArea","90000");
		
	 	for (int i=0;i<testSet.GetLength(0);i++) {
			try {
				
				Console.WriteLine("");
				Console.WriteLine("---  ---------------------------");
				Console.WriteLine("Scanning File: "+testSet[i]);
				Console.WriteLine("");
				scanImage(testSet[i]);
				Console.WriteLine("------------------------------");
			} catch (Exception e) {
	 			Console.WriteLine(e.Message);
				Console.WriteLine(e.StackTrace);
			}
		}	
		
		Console.WriteLine("END.");
	}
	
	/**
	 * scan file
	 * @param file image file

	 * @throws Exception
	 */
	 public void scanImage(string file)  {
		
		 Bitmap im=(Bitmap) loadImage(dir+file);
	
		PDF417Reader reader=new PDF417Reader();
		
		Console.WriteLine("Start "+DateTime.Now);
		RImage rim=new RImage( im);

        PDF417Data[] barcodes=reader.Read(rim);
		rim=null;
		im=null;
		Console.WriteLine("End "+DateTime.Now);		
		
		
		if (barcodes.GetLength(0)==0) Console.WriteLine("*** NO BARCODE FOUND ***");
		
		for (int i=0;i<barcodes.GetLength(0);i++) {
			
			if (barcodes[i].GetConfidence()<0) Console.WriteLine("\bBarcode found but It CONTAINS ERRORS which could not be corrected "+barcodes[i].ToString());
			else if (barcodes[i].GetConfidence()>0) Console.WriteLine("\nBarcode  found and errors corrected "+barcodes[i].ToString());
			else Console.WriteLine("\nBarcode  found "+barcodes[i].ToString());
			
			if (barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_SEGMENT)!=null) {
				Console.WriteLine("Macro PDF information:");
				Console.WriteLine("     Segment index: "+barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_SEGMENT));
				Console.WriteLine("     Segment file Id "+barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_FILEID));
				Object o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_SEGMENT_COUNT);
				if (o!=null) Console.WriteLine("     Segment total count: "+o);
				o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_FILENAME);
				if (o!=null) Console.WriteLine("     Filename: "+o);
				o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_FILESIZE);
				if (o!=null) Console.WriteLine("     File size: "+o);
				o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_TIMESTAMP);
				if (o!=null) Console.WriteLine("     TimeStamp: "+o);				
				o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_SENDER);
				if (o!=null) Console.WriteLine("     Sender: "+o);
				o=barcodes[i].GetMacroPDFField(PDF417Data.MACROPDF_ADRESSEE);
				if (o!=null) Console.WriteLine("     Adresse: "+o);
				
			}
			
		}
						
	}
	
	/**
	 * load image from file
	 */
	public Image loadImage(String f) {
			
	 	Image bp= Bitmap.FromFile(f);
	 	Bitmap b2=new Bitmap(bp.Width,bp.Height,PixelFormat.Format24bppRgb);
	 	Graphics g=Graphics.FromImage(b2);
	 	g.DrawImage(bp,0,0,bp.Width,bp.Height);
	 	g.Dispose();
	 	return b2;

	}	
}
